==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/account/login.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	login.lang.inc.php 2019-06-03
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2015 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'heading_login'         => 'Melden Sie sich an',
    'text_email'            => 'E-Mail-Adresse:',
    'text_guest'            => 'Durch Ihre Bestellung als Gast wird kein eigenes Kundenkonto für Sie angelegt. Dies bedeutet, dass Sie bei einer erneuten Bestellung alle Daten erneut eingeben müssen.',
    'text_lost_password'    => 'Passwort vergessen?',
    'text_new'              => 'Legen Sie ein Kundenkonto an, um schneller bestellen zu können und jederzeit den Status Ihrer Bestellung zu verfolgen.',
    'text_new_account_only' => 'Wenn Sie noch kein Kundenkonto besitzen, können Sie hier eines anlegen. Sie können sich damit in Zukunft schnell einloggen und jederzeit den Status Ihrer Bestellungen verfolgen.',
    'text_new_guest_only'   => 'Bitte geben Sie Ihre Kundendaten ein, um mit der Bestellung fortzufahren.',
    'text_new_guest_option' => 'Sie können auch ohne dauerhafte Registrierung als Gast fortfahren.',
    'text_password'         => 'Passwort:',
    'text_returning'        => '',
    'title_guest'           => 'Als Gast bestellen',
    'title_new'             => 'Ich bin ein neuer Kunde',
    'title_returning'       => 'Ich bin bereits Kunde',
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/account/login.lang.inc.php <==
<?php
/* --------------------------------------------------------------
	login.lang.inc.php 2025-01-09
	Gambio GmbH
	http://www.gambio.de
	Copyright (c) 2025 Gambio GmbH
	Released under the GNU General Public License (Version 2)
	[http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'heading_login'         => 'Melden Sie sich an',
    'text_email'            => 'E-Mail',
    'text_guest'            => 'Durch Ihre Bestellung als Gast wird kein eigenes Kundenkonto für Sie angelegt. Dies bedeutet, dass Sie bei einer erneuten Bestellung alle Daten erneut eingeben müssen.',
    'text_lost_password'    => 'Passwort vergessen?',
    'text_new'              => 'Legen Sie ein Kundenkonto an, um schneller bestellen zu können und jederzeit den Status Ihrer Bestellung zu verfolgen.',
    'text_new_account_only' => 'Wenn Sie noch kein Kundenkonto besitzen, können Sie hier eines anlegen. Sie können sich damit in Zukunft schnell einloggen und jederzeit den Status Ihrer Bestellungen verfolgen.',
    'text_new_guest_only'   => 'Bitte geben Sie Ihre Kundendaten ein, um mit der Bestellung fortzufahren.',
    'text_new_guest_option' => 'Sie können auch ohne dauerhafte Registrierung als Gast fortfahren.',
    'text_password'         => 'Passwort',
    'text_returning'        => '',
    'title_guest'           => 'Als Gast bestellen',
    'title_new'             => 'Ich bin ein neuer Kunde',
    'title_returning'       => 'Ich bin bereits Kunde',
];
